@@ -1,4 +1,4 @@
-# Copyright (c) 2020 CRS4
+# Copyright (c) 2019-2021 CRS4
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -1172,6 +1172,17 @@ def Normalize(src, dst, mean, std):
     return _ecvl.Normalize(src, dst, mean, std)
 
 
+def CenterCrop(src, dst, size):
+    """\
+    Crop the given image at the center.
+
+    :param src: input image.
+    :param dst: output image.
+    :param size: list of integers [w, h] specifying the desired output size
+    """
+    return _ecvl.CenterCrop(src, dst, size)
+
+
 # == dataset_parser ==
 
 class SplitType(_ecvl.SplitType):
@@ -1377,13 +1388,15 @@ class AugRotate(_ecvl.AugRotate):
         return _ecvl.AugRotate(txt)
 
     def __init__(self, angle, center=None, scale=1.0,
-                 interp=InterpolationType.linear):
+                 interp=InterpolationType.linear,
+                 gt_interp=InterpolationType.nearest):
         """\
         :param angle: range of degrees ``[min, max]`` to randomly select from
         :param center: a list of floats representing the coordinates of the
           rotation center. If None, the center of the image is used
         :param scale: scaling factor
         :param interp: InterpolationType to be used
+        :param gt_interp: InterpolationType to be used for ground truth
         """
         if center is None:
             center = []
@@ -1404,11 +1417,13 @@ class AugResizeDim(_ecvl.AugResizeDim):
         """
         return _ecvl.AugResizeDim(txt)
 
-    def __init__(self, dims, interp=InterpolationType.linear):
+    def __init__(self, dims, interp=InterpolationType.linear,
+                 gt_interp=InterpolationType.nearest):
         """\
         :param dims: list of integers that specifies the new size of each
           dimension
         :param interp: InterpolationType to be used
+        :param gt_interp: InterpolationType to be used for ground truth
         """
         _ecvl.AugResizeDim.__init__(self, dims, interp)
 
@@ -1427,11 +1442,13 @@ class AugResizeScale(_ecvl.AugResizeScale):
         """
         return _ecvl.AugResizeScale(txt)
 
-    def __init__(self, scale, interp=InterpolationType.linear):
+    def __init__(self, scale, interp=InterpolationType.linear,
+                 gt_interp=InterpolationType.nearest):
         """\
         :param scale: list of floats that specifies the scale to apply to
           each dimension
         :param interp: InterpolationType to be used
+        :param gt_interp: InterpolationType to be used for ground truth
         """
         _ecvl.AugResizeScale.__init__(self, scale, interp)
 
@@ -1831,6 +1848,27 @@ class AugNormalize(_ecvl.AugNormalize):
         _ecvl.AugNormalize.__init__(self, mean, std)
 
 
+class AugCenterCrop(_ecvl.AugCenterCrop):
+    """\
+    Augmentation wrapper for CenterCrop.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create an AugCenterCrop from a text description, e.g.::
+
+            a = AugCenterCrop('size=(10, 20)')
+        """
+        return _ecvl.AugCenterCrop(txt)
+
+    def __init__(self, size):
+        """\
+        :param size: list of integers [w, h] specifying the output size
+        """
+        _ecvl.AugCenterCrop.__init__(self, size)
+
+
 # == support_imgcodecs ==
 
 class ImReadMode(_ecvl.ImReadMode):
